<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.
// Generated by DeepSeek.

/**
 * Library file for plugin 'local_quizessaygrader'.
 *
 * @package     local_quizessaygrader
 * @copyright   2025 Alex Orlov <snickser@gmail.com>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

define('CLI_SCRIPT', true);

require_once(__DIR__ . '/../../../config.php');
require_once($CFG->libdir . '/clilib.php');
require_once(__DIR__ . '/../lib.php');

// Error reporting settings.
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// Command line parameters processing.
[$options, $unrecognized] = cli_get_params([
    'help' => false,
    'courseid' => 0,
    'quizid' => 0,
    'userid' => 0,
    'verbose' => false,
    'dryrun' => false,
    'maxusers' => 0,
], [
    'h' => 'help',
    'c' => 'courseid',
    'q' => 'quizid',
    'u' => 'userid',
    'v' => 'verbose',
    'd' => 'dryrun',
    'm' => 'maxusers',
]);

if ($options['help']) {
    echo "Script for transferring essay grades between quiz attempts

Options:
-h, --help        Print this help
-c, --courseid    Process only specified course
-q, --quizid      Process only specified quiz
-u, --userid      Process only specified user
-v, --verbose     Verbose output
-d, --dryrun      Test mode (no DB changes)
-m, --maxusers    Maximum number of users to process

Examples:
php transfer_essay_grades.php
php transfer_essay_grades.php --courseid=2 --verbose
php transfer_essay_grades.php --quizid=5 --dryrun --maxusers=100
";
    exit(0);
}

// Execute.
local_quizessaygrader_run(
    $options['courseid'],
    $options['quizid'],
    $options['userid'],
    $options['verbose'],
    $options['dryrun']
);
